pilas.escenas

Package pilas :: Module escenas |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.escenas

     1  # -*- encoding: utf-8 -*-
     2  # pilas engine - a video game framework.
     3  #
     4  # copyright 2010 - hugo ruscitti
     5  # license: lgplv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10
    11 -class Escena(object):
    12      "Escena abstracta."
    13
    14 -    def __init__(self):
    15          #pilas.mundo.definir_escena(self)
    16          escena_aviso = pilas.escena.Aviso()
    17          pilas.cambiar_escena(escena_aviso)
    18
    19 -    def iniciar(self):
    20          pass
    21
    22 -    def terminar(self):
    23          pass
    24
    25
    26 -class Normal(Escena):
    27      "Representa la escena inicial mas simple."
    28
    29 -    def __init__(self, color_de_fondo=None):
    30          Escena.__init__(self)
    31          self.fondo = pilas.fondos.Color(color_de_fondo)
    32